==> haskell-svg-builder-0.1.1-295.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-svg-builder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 svg-builder
version:              0.1.1
visibility:           public
id:                   svg-builder-0.1.1-APoBSRsQhY8C0zzsRUvP0p
key:                  svg-builder-0.1.1-APoBSRsQhY8C0zzsRUvP0p
license:              BSD-3-Clause
copyright:            2016 Jeffrey Rosenbluth
maintainer:           jeffrey.rosenbluth@gmail.com
author:               Jeffrey Rosenbluth
homepage:             https://github.com/diagrams/svg-builder.git
synopsis:             DSL for building SVG.
description:          Fast, easy to write SVG.
category:             Graphics
abi:                  70410c38c7e8cba9fb4b85408079b606
exposed:              True
exposed-modules:
    Graphics.Svg Graphics.Svg.Attributes Graphics.Svg.Core
    Graphics.Svg.Elements Graphics.Svg.Path

import-dirs:          /usr/lib/ghc-9.6.6/site-local/svg-builder-0.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/svg-builder-0.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/svg-builder-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-svg-builder
hs-libraries:         HSsvg-builder-0.1.1-APoBSRsQhY8C0zzsRUvP0p
depends:
    base-4.18.2.1 blaze-builder-0.4.4.1-KJNFYglh6UuC57b0V7Eyim
    bytestring-0.11.5.3 hashable-1.4.7.0-DKTv0aQgcZmBEMi2BPTV4Z
    text-2.0.2 unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu

haddock-interfaces:   /usr/share/doc/haskell-svg-builder/html/svg-builder.haddock
haddock-html:         /usr/share/doc/haskell-svg-builder/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-svg-builder-0.1.1-296-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-svg-builder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 svg-builder
version:              0.1.1
visibility:           public
id:                   svg-builder-0.1.1-GPQSFJ1K1xz9DWb8z5b9XG
key:                  svg-builder-0.1.1-GPQSFJ1K1xz9DWb8z5b9XG
license:              BSD-3-Clause
copyright:            2016 Jeffrey Rosenbluth
maintainer:           jeffrey.rosenbluth@gmail.com
author:               Jeffrey Rosenbluth
homepage:             https://github.com/diagrams/svg-builder.git
synopsis:             DSL for building SVG.
description:          Fast, easy to write SVG.
category:             Graphics
abi:                  221b2dd7e0b269d11e828a984cbc5b7b
exposed:              True
exposed-modules:
    Graphics.Svg Graphics.Svg.Attributes Graphics.Svg.Core
    Graphics.Svg.Elements Graphics.Svg.Path

import-dirs:          /usr/lib/ghc-9.6.6/site-local/svg-builder-0.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/svg-builder-0.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/svg-builder-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-svg-builder
hs-libraries:         HSsvg-builder-0.1.1-GPQSFJ1K1xz9DWb8z5b9XG
depends:
    base-4.18.2.1 blaze-builder-0.4.4.1-3Jo4fZFJ11sJTzGUvOFfLv
    bytestring-0.11.5.3 hashable-1.4.7.0-1GSULm1uRgQBgX6mu6tvYD
    text-2.0.2 unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5

haddock-interfaces:   /usr/share/doc/haskell-svg-builder/html/svg-builder.haddock
haddock-html:         /usr/share/doc/haskell-svg-builder/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
